@@ -8,7 +8,7 @@ data_plot.compare_performance <- function(x, data = NULL, ...) {
   if ("BF" %in% colnames(x)) x$BF[is.na(x$BF)] <- 1
 
   # normalize indices, for better comparison
-  x <- datawizard::data_rescale(x, exclude = "Model", to = c(.1, 1))
+  x <- datawizard::rescale(x, exclude = "Model", to = c(.1, 1))
 
   # recode some indices, so higher values = better fit
   for (i in c("AIC", "BIC", "AICc", "RMSE", "Sigma")) {
@@ -74,7 +74,6 @@ data_plot.compare_performance <- function(x, data = NULL, ...) {
 #' @importFrom ggplot2 .data
 #' @export
 plot.see_compare_performance <- function(x, size_line = 1, ...) {
-
   # We may think of plotting the "performance scores" as bar plots,
   # however, the "worst" model always has a score of zero, so no bar
   # is shown - this is rather confusing. One option might be to only
