@@ -15,7 +15,7 @@ data_plot.parameters_brms_meta <- function(x, data = NULL, normalize_height = TR
 
   # normalize height
   if (isTRUE(normalize_height)) {
-    dataplot$y <- datawizard::data_rescale(dataplot$y, to = c(0, .9))
+    dataplot$y <- datawizard::rescale(dataplot$y, to = c(0, .9))
   }
 
   # summary
@@ -136,7 +136,6 @@ plot.see_parameters_brms_meta <- function(x,
                                           normalize_height = TRUE,
                                           show_labels = TRUE,
                                           ...) {
-
   # save model for later use
   model <- tryCatch(
     {
