@@ -50,7 +50,6 @@ plot.see_parameters_model <- function(x,
                                       show_density = FALSE,
                                       log_scale = FALSE,
                                       ...) {
-
   # retrieve settings ----------------
   model_attributes <- attributes(x)[!names(attributes(x)) %in% c("names", "row.names", "class")]
 
@@ -328,7 +327,6 @@ plot.see_parameters_model <- function(x,
 
 
   if (is_meta || is_meta_bma) {
-
     # plot setup for metafor-objects
     p <- ggplot2::ggplot(x, ggplot2::aes(y = .data$Parameter, x = .data$Coefficient, color = .data$group)) +
       ggplot2::geom_vline(ggplot2::aes(xintercept = y_intercept), linetype = "dotted") +
@@ -355,7 +353,6 @@ plot.see_parameters_model <- function(x,
       p <- p + ggplot2::geom_point(size = x$size_point * size_point, shape = x$shape)
     }
   } else if (isTRUE(multiple_ci)) {
-
     # plot setup for model parameters with multiple CIs
     x$CI <- as.character(x$CI)
 
@@ -393,7 +390,6 @@ plot.see_parameters_model <- function(x,
       )
     }
   } else {
-
     # plot setup for regular model parameters
     x$group <- factor(x$Coefficient < y_intercept, levels = c(FALSE, TRUE))
     if (all(x$group == "TRUE")) {
@@ -465,7 +461,7 @@ plot.see_parameters_model <- function(x,
   # largest data points that are within this range. Thereby we have the pretty
   # values we can use as breaks and labels for the scale...
 
-  if (exponentiated_coefs & log_scale) {
+  if (exponentiated_coefs && log_scale) {
     range <- 2^c(-24:16)
     x_low <- which.min(min_ci > range) - 1
     x_high <- which.max(max_ci < range)
@@ -544,7 +540,10 @@ plot.see_parameters_model <- function(x,
     } else {
       p + labs(
         y = parameter_label,
-        x = ifelse(is.null(coefficient_name), ifelse(exponentiated_coefs, "Exp(Estimate)", "Estimate"), coefficient_name),
+        x = ifelse(is.null(coefficient_name),
+          ifelse(exponentiated_coefs, "Exp(Estimate)", "Estimate"),
+          coefficient_name
+        ),
         colour = "CI"
       )
     }
@@ -558,7 +557,7 @@ plot.see_parameters_model <- function(x,
   measure <- .meta_measure(meta_measure)
 
   dat_funnel <- data.frame(
-    se_range = datawizard::data_rescale(1:(nrow(x) * 10), to = c(0, max_y))
+    se_range = datawizard::rescale(1:(nrow(x) * 10), to = c(0, max_y))
   )
   estimate <- x$Coefficient[x$Parameter == "Overall"]
 
@@ -573,8 +572,18 @@ plot.see_parameters_model <- function(x,
   ggplot(x, aes(x = .data$Coefficient, y = .data$SE)) +
     scale_y_reverse(expand = c(0, 0), limits = c(max_y, 0)) +
     geom_polygon(data = d_polygon, aes(.data$x, .data$y), fill = "grey80", alpha = .3) +
-    geom_line(data = dat_funnel, mapping = aes(x = .data$ci_low, y = .data$se_range), linetype = "dashed", color = "grey70") +
-    geom_line(data = dat_funnel, mapping = aes(x = .data$ci_high, y = .data$se_range), linetype = "dashed", color = "grey70") +
+    geom_line(
+      data = dat_funnel,
+      mapping = aes(x = .data$ci_low, y = .data$se_range),
+      linetype = "dashed",
+      color = "grey70"
+    ) +
+    geom_line(
+      data = dat_funnel,
+      mapping = aes(x = .data$ci_high, y = .data$se_range),
+      linetype = "dashed",
+      color = "grey70"
+    ) +
     theme_modern() +
     geom_vline(xintercept = estimate, colour = "grey70") +
     geom_point(size = size_point, colour = "#34465d") +
