@@ -71,7 +71,7 @@ data_plot.rope <- function(x, data = NULL, show_intercept = FALSE, ...) {
 #'
 #' @inheritParams data_plot
 #' @inheritParams plot.see_bayesfactor_parameters
-#' @inheritParams plot.see_cluster_analysis
+#' @inheritParams plot.see_parameters_model
 #'
 #' @return A ggplot2-object.
 #'
@@ -85,7 +85,7 @@ data_plot.rope <- function(x, data = NULL, show_intercept = FALSE, ...) {
 #'   plot(result)
 #' }
 #' }
-#' @importFrom rlang .data
+#' @importFrom ggplot2 .data
 #' @export
 plot.see_rope <- function(x,
                           data = NULL,
@@ -107,6 +107,8 @@ plot.see_rope <- function(x,
   # get labels
   labels <- .clean_parameter_names(x$y, grid = !is.null(n_columns))
 
+  insight::check_if_installed("ggridges")
+
   p <- ggplot(
     as.data.frame(x),
     aes(
